#
# spec file for package gjiten
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gjiten
BuildRequires:  edict
BuildRequires:  intltool
BuildRequires:  libglade2-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  perl-XML-Parser
BuildRequires:  scrollkeeper
BuildRequires:  sgml-skel
BuildRequires:  update-desktop-files
BuildRequires:  w3m
BuildRequires:  xmlto
%if 0%{?suse_version} >= 1130
BuildRequires:  libgnome-keyring-devel
%else
BuildRequires:  gnome-keyring-devel
%endif
Requires:       edict
Provides:       locale(libgnome:ja)
Version:        2.6
Release:        lp151.2.3
Url:            http://gjiten.sourceforge.net/
# CVS version is here:
#  cvs -d:pserver:anonymous@gjiten.cvs.sourceforge.net:/cvsroot/gjiten login
#  (empty password)
#  cvs -d:pserver:anonymous@gjiten.cvs.sourceforge.net:/cvsroot/gjiten checkout gjiten
Source:         http://gjiten.sourceforge.net/gjiten-%version.tar.gz
Patch0:         gjiten.patch
Patch1:         %name-desktop.patch
Patch3:         configure.patch
Patch4:         schemas.patch
Patch5:         skip-validation.patch
Patch348100:    bugzilla-348100-empty-radicals-window.patch
Patch6:         gjiten-automake-fix.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Japanese Dictionary Browser for GNOME/GTK+
License:        GPL-2.0+
Group:          Productivity/Office/Dictionary
%define gnome_prefix %(pkg-config --variable=prefix libgnomeui-2.0)
%if "%gnome_prefix" == "/usr"
%define gnome_etc /etc
%gconf_schemas_prereq
%else
%define gnome_etc /etc%gnome_prefix
PreReq:         gconf2
%endif

%description
Gjiten is a GNOME-based Japanese dictionary program. It uses some of
the xjdic code written by Jim Breen and his dictionary files.  Gjiten
also has a kanji dictionary. Any combination of stroke count, radicals,
and search key can be used for kanji lookups.  It requires a working X
input method (such as kinput2) for Japanese input.



Authors:
--------
    Botond Botyanszki <boti@beer.com>

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch348100 -p1
%patch6 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS" 
./autogen.sh --prefix=%{gnome_prefix} \
            --mandir=%{_mandir} \
            --infodir=%{_infodir} \
	    --with-gnome=%{gnome_prefix} \
	    --with-gconf-schema-file-dir=%{gnome_etc}/gconf/schemas \
            %{_target_cpu}-suse-linux
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
mkdir -p -m 755 $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}
cp AUTHORS BUGS COPYING ChangeLog* INSTALL* NEWS* README* TODO \
   $RPM_BUILD_ROOT/%{gnome_prefix}/share/doc/gjiten/gjiten-doc.ja.html \
   $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}
pushd $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}
    for i in $RPM_BUILD_ROOT%{gnome_prefix}/share/gnome/help/gjiten/* 
    do
        ln -sf $( echo $i | sed "s%%^$RPM_BUILD_ROOT%%%%g" ) .
    done
popd
%find_lang gjiten
%if %suse_version > 1020
%find_gconf_schemas
cat %{name}.lang %{name}.schemas_list >%{name}.lst
%else
cat %{name}.lang >%{name}.lst
%endif
%suse_update_desktop_file %name Office Dictionary 
%if %suse_version > 1020

%pre -f %{name}.schemas_pre

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun
%else

%post
export GCONF_CONFIG_SOURCE=`./%{gnome_prefix}/bin/gconftool-2 --get-default-source`
./%{gnome_prefix}/bin/gconftool-2 --makefile-install-rule ./%{gnome_etc}/gconf/schemas/gjiten.schemas >/dev/null
./%{gnome_prefix}/bin/gconftool-2 --makefile-install-rule ./%{gnome_etc}/gconf/schemas/gjiten-dicfiles.schemas >/dev/null
%endif

%clean
#rm -rf $RPM_BUILD_ROOT;

%files -f %{name}.lst
%defattr(-, root, root)
%doc %{_defaultdocdir}/%{name}/
%{gnome_prefix}/bin/*
%dir %{gnome_prefix}/share/application-registry
%dir %{_datadir}/omf
%{gnome_prefix}/share/application-registry/gjiten.desktop
%{gnome_prefix}/share/applications/gjiten.desktop
%{gnome_prefix}/share/gjiten
%{gnome_prefix}/share/gnome/help/gjiten
%{gnome_prefix}/share/locale/*/LC_MESSAGES/gjiten.mo
%{gnome_prefix}/share/omf/gjiten
%{gnome_prefix}/share/pixmaps/*
%exclude %{gnome_prefix}/share/doc/gjiten/gjiten-doc.ja.html
%if %suse_version <= 1020
%{gnome_etc}/gconf/schemas/*
%endif
%{_mandir}/man1/*

%changelog
* Sun Jul 27 2014 hillwood@linuxfans.org
- Fix build for openSUSE 13.2
* Wed Feb 15 2012 tiwai@suse.de
- clean up spec file: fix Makefile.am to build properly, remove
  obsoleted suse macro
- Enable parallel builds
* Fri Oct 14 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Jan  4 2010 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel on 11.3 and later, following the module
  split upstream.
* Tue Dec 18 2007 mfabian@suse.de
- Bugzilla #348100: sometimes the radicals window in gjiten
  was empty. Fix from upstream CVS.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed false dependency on avahi.
* Mon May 21 2007 mfabian@suse.de
- fix build on STABLE (remove X-SuSE-translate=true from .desktop
  file).
* Mon Mar 12 2007 mfabian@suse.de
- fix build on STABLE: adapt installtion of schemas for
  openSUSE > 10.2.
* Wed Jan 24 2007 mfabian@suse.de
- make it build in older distributions in the openSUSE build
  service.
* Wed Jan 24 2007 mfabian@suse.de
- update to 2.6:
  • DTD location changed in docbook doc (John Thacker).
  • Don't look up kanji if there is a selection.
  • Configurable toolbar/menubar was causing problems, removed.
  • Add de_CH translation and close debian bug #314089.
  • Japanese translation update (Daichi Kawahata).
  • Shade unavailable radicals in radical window
  • radkfile update.
- make it build on older openSUSE releases by determining
  gnome_prefix automatically.
- use find_lang macro.
* Mon Jan 22 2007 aj@suse.de
- Move to /usr
* Sat Oct  7 2006 aj@suse.de
- Cleanup BuildRequires.
* Thu Sep  7 2006 mfabian@suse.de
- update to CVS version 2.5.20060907 to fix the problem that the
  radicals are not displayed in the result field when using
  the kanji dictionary.
* Thu Sep  7 2006 mfabian@suse.de
- update to 2.5.
  • Kanji can be clicked in WordDic for KanjiDic lookup.
    (Mboso Sampson)
  • Regenerated autoconf scripts for kfreebsd support.
  • Fixed possible buffer overflows.
  • Fixed stroke count search when irrelevant results showed up.
  • History buffer overrun fixed (John Thacker).
  • Updated spec for FC3
  • Fixed segfault with invalid dicfile in the schema.
- remove schemasdir.patch (included upstream).
* Fri Jun 16 2006 schwab@suse.de
- Fix syntax error in configure script.
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(libgnome:ja)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jun 21 2005 mfabian@suse.de
- set correct default dictionary paths and other default values
  in schemas.in.
* Fri Jun 10 2005 mfabian@suse.de
- update to 2.4.
- Gettext fix for kanji info pref dialog. (Daichi Kawahata)
- KanjiDic segv on CTRL-Q fixed. (Alexis S. L. Carvalho)
- Japanese translation fixes and desktop file i18n.
  (Daichi Kawahata)
- Dicfile match colorization fix for gettext translation.
- KanjiDic history width problem fixed.
- Added support for the Chinese CEDICT dictionary.
- German translation update. (Gregor Riepl)
- Optional unicode radicals in KanjiDic.
- Don't limit if result limit is < 1.
- Perl script for automated dictionary setup
  (system-wide or user-only).
- Gconf schema for system-wide settings.
- Fixed help menu.
* Tue Jan 25 2005 uli@suse.de
- update -> 2.3 (search hiragana on katakana input and vice versa,
  code cleanup, fixes 'whole expression' matching with newer edict
  files, unlimited number of dictionary files, radkfile updated,
  bugfixes, minor enhancements)
* Tue Dec 14 2004 hvogel@suse.de
- fix desktop file
* Wed May 26 2004 ro@suse.de
- do not define GTK_DISABLE_DEPRECATED
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sun Aug 24 2003 mfabian@suse.de
- update to 2.1 (Gnome2 version).
  The EDICT dictionaries MUST be UTF-8 encoded now!
* Fri Jun 13 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Sat Jan 19 2002 mfabian@suse.de
- update to gjiten-1.0
  New stuff and fixes in v1.0 according to the author
  Botond Botyanszki <boti@beer.com>:
  - "Reply overrun" crashes with the JP-German GDICT fixed.
  - Search options are saved on exit.
  - Limit search results in word dictionary.
  - Kanji info window moved to the main KanjiDic window.
  - KanjiDic kanji-info history.
  - Automatic vertical scrollbars.
  - Bigger fonts for KanjiDic.
  - Word dictionary fonts also customizable in preferences.
* Sat Nov  3 2001 mfabian@suse.de
- update to gjiten-0.9
- remove gjiten-0.8-fix-for-crash-with-fvwm2.patch
  (included upstream)
- remove gjiten-0.8-fix-for-64bit.patch (included upstream)
  New stuff and fixes in v0.9 according to the author
  Botond Botyanszki <boti@beer.com>:
  - History saving (up to 50 entries) on exit.
  - Auto adjust search options if no match is found.
  - Now starts up properly with gnome/gtk specific cmd line options.
  - Updated for the IA64 architecture.
  - Shouldn't crash with Fvwm2 anymore.
  - dpkg-buildpackage should work under debian potato from now.
  - Dicfile limit raised to 40.
  - Added Back/Forward buttons to the toolbar.
  - Radkfile updated.
  - Fixed history behaviour (garbage, whitespace, case sensitivity)
  - Segfault on unconfigured exit fixed.
  - Numerous small bugfixes.
* Sun Sep 16 2001 mfabian@suse.de
- make it work on ia64
- fix for crash when using gjiten with fvwm 2.4.0
* Tue Sep  4 2001 schwab@suse.de
- Fix portability.
* Tue Sep  4 2001 mfabian@suse.de
- upgrade to gjiten-0.8
- remove gjiten-0.7-setlocale.patch, now included upstream
- share same data with xjdic and
  make gjiten require xjdic-data and xjdic-indices instead of
  including the same data in gjiten as well
- default dictionary location changed to /usr/share/edict
* Tue Mar 20 2001 uli@suse.de
- added esound* to neededforbuild
* Tue Jan  2 2001 mfabian@suse.de
- corrected problem with setlocale():
  setlocale() must be called before bindtextdomain() and
  textdomain()
* Thu Nov  9 2000 Mike Fabian <mfabian@suse.de>
- new package: gjiten-0.7
